%cropfig
% Function which transforms a figure window to crop to the image contained
% within it.
%
% LAST UPDATED by Andy French 24rd June 2011

function cropfig( fig, ax )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Define border number of pixels
border = 5;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Point to figure and axes specified by function
figure(fig);
axes(ax);

%Get position vectors for figure and axis and units
pos_fig = get(fig,'position');
pos_ax = get(ax,'position');
orig_ax_units = get(ax,'units');
orig_fig_units = get(fig,'units');

%Modify figure to have the same aspect ratio as the axes
aspect = pos_ax(4)/pos_ax(3);
set(fig,'position',[ pos_fig(1),...
    pos_fig(2),...
    pos_fig(3),...
    pos_fig(3)*aspect ] );

%Stretch axes to fill figure
set(ax,'position',[0 0 1 1]);

%Set background color of axes to be white
background_color = get(fig,'color');
set(fig,'color',[1 1 1]);

%Obtain a bitmap image
f=getframe(fig);

%Determine mean colour matrix
m = mean(f.cdata,3);
dim = size(m);
width_pix = dim(2);
height_pix = dim(1);

%Determine maximum and minimum indices of pixels which are NOT white
[row_ind,col_ind] = find(m~=255);
min_row = min(row_ind);
max_row = max(row_ind);
min_col = min(col_ind);
max_col = max(col_ind);

%Resize figure to crop to extent of image
%Get position vectors for figure and axis
set(fig,'units','pixels');
set(ax,'units','pixels');
pos_fig = get(fig,'position');
pos_ax = get(ax,'position');

%Shift axes so that bottom left hand corner is the bottom left hand corner
%of the image
set(ax,'position',[ pos_ax(1)-min_col+border,...
    pos_ax(2)-height_pix+max_row+border,...
    pos_ax(3),...
    pos_ax(4) ] );

%Modify figure to have the same aspect ratio as the image
set(fig,'position',[ pos_fig(1),...
    pos_fig(2),...
    max_col-min_col+2*border,...
    max_row-min_row+2*border ] );

%Return units to original settings
set(fig,'units',orig_fig_units);
set(ax,'units',orig_ax_units);
set(fig,'color',background_color);

%Center figure
set(fig,'position',figcenter('current'));

%%

function cropfigtest
peaks;
axis vis3d
axis tight
axis off
title('')
fig=  gcf;
ax = gca;
cropfig(fig,ax)

%End of code