%volume
% Visualize a scalar field defined by a 3D matrix V defined at points
% contained within an identically sized set of cartesian matrices X,Y,Z.
% These must be of a 'plaid' form - i.e. equivalent to the output of
% meshgrid.
%
% A volume is visualized by plotting nested shells of volume iso-surfaces with
% varying transparency. The iso-surface values are provided in vector v.
%
% LAST UPDATED by Andy French Dec 2011

function volume( x,y,z,V,v,t,cax )

%Point to current active figure, or create a new one if one doesn't exist.
fig = gcf;

%Make figure window white and set rendering option to OpenGL. Use ZBuffer
%if your graphics card doesn't support this.
set(fig,'color',[1 1 1],'renderer','opengl');

%Obtain maximum and minimum values of V
Vmax = max(max(max(V)));
Vmin = min(min(min(V)));

%Make sure v is within the range Vmin to Vmax
v(v>Vmax) = Vmax;
v(v<Vmin) = Vmin;

%Make sure t is within the range 0 to 1
t(t>1) = 1;
t(t<0) = 0;

%Set limits of V to correspond to colormap
if isempty(cax)==1
    caxis( [Vmin,Vmax] );
else
    caxis( cax );
end
    
%Visualize volume by plotting nested shells of volume iso-surfaces with
%varying transparency. Use current colormap to set the colour of the shells
for n=1:length(v)
    [R,G,B] = colfromcolormap( v(n) );
    p = patch( isosurface(x,y,z,V, v(n) ),...
        'Facealpha',t(n),'FaceColor', [R,G,B], 'EdgeColor', 'none');
    isonormals(x,y,z,V,p);
end
view(3); 
daspect([1 1 1]);

%%

function volume_test

cax = [];
[x,y,z,V] = flow;
vmax = max(max(max(V)));
vmin = min(min(min(V)));
k = [0.1,0.5,0.7,0.9,0.95];
v = vmin + k*(vmax-vmin);
t = 0.1+0.9*exp(4*(k-1));
volume( x,y,z,V,v,t,cax );
colorbar
grid on
xlabel('x')
ylabel('y')
zlabel('z')
title('Test of volume.m')
view(63,18);
lighting phong
camlight

%End of code