%volume2
% Visualize a scalar field defined by a 3D matrix V defined at points
% contained within an identically sized set of cartesian matrices X,Y,Z.
% These must be of a 'plaid' form - i.e. equivalent to the output of
% meshgrid.
%
% Volume visualisation using slice planes. Taken from the MATLAB help.
% Example: "Slicing fluid flow data."

function volume2(x,y,z,v,cax)

%Point to current active figure, or create a new one if one doesn't exist.
fig = gcf;

%Make figure window white and set rendering option to OpenGL. Use ZBuffer
%if your graphics card doesn't support this.
set(fig,'color',[1 1 1],'renderer','opengl');

%Obtain maximum and minimum values of V
vmax = max(max(max(v)));
vmin = min(min(min(v)));

%Get axis limits
xmin = min(x(:)); 
ymin = min(y(:)); 
zmin = min(z(:));
xmax = max(x(:)); 
ymax = max(y(:)); 
zmax = max(z(:));

%Define 45 degree rotated slice plane
hslice = surf(linspace(xmin,xmax,100),...
	linspace(ymin,ymax,100),...
	zeros(100));
rotate(hslice,[-1,0,0],-45)
xd = get(hslice,'XData');
yd = get(hslice,'YData');
zd = get(hslice,'ZData');
delete(hslice)

%Plot 45 deg slice plane and colour using v values within the slice
h = slice(x,y,z,v,xd,yd,zd);
set(h,'FaceColor','interp',...
	'EdgeColor','none',...
	'DiffuseStrength',.8)

%Add x slice plane
hold on
hx = slice(x,y,z,v,xmax,[],[]);
set(hx,'FaceColor','interp','EdgeColor','none')

%Add y slice plane
hy = slice(x,y,z,v,[],ymax,[]);
set(hy,'FaceColor','interp','EdgeColor','none')

%Add z slice plane
hz = slice(x,y,z,v,[],[],zmin);
set(hz,'FaceColor','interp','EdgeColor','none')

%Set limits of V to correspond to colormap
if isempty(cax)
    caxis( [vmin,vmax] );
else
    caxis( cax );
end

%Set data view options
view(3); 
daspect([1 1 1]);

%%

function volume2_test

cax = [];
[x,y,z,V] = flow;
volume2( x,y,z,V,cax );
lighting phong
%camlight
box on
%camproj perspective
grid on
xlabel('x')
ylabel('y')
zlabel('z')
title('Test of volume2.m')
colorbar('EastOutside')

%End of code