%volume3
% Visualize a scalar field defined by a 3D matrix v defined at points
% contained within an identically sized set of cartesian matrices X,Y,Z.
% These must be of a 'plaid' form - i.e. equivalent to the output of
% meshgrid.
%
% Scalar field visualization via a PNG montage of N x,y or z plane slices.
%
% LAST UPDATED by Andy French Dec 2011

function volume3( dir,filename,x,y,z,v,xyz_str,N,cax )

%Create a new figure window. Make figure window white and set rendering
%option to OpenGL. Use ZBuffer if your graphics card doesn't support this.
figure('color',[1 1 1],'renderer','opengl');

%Obtain maximum and minimum values of v
vmax = max(max(max(v)));
vmin = min(min(min(v)));

%Get axis limits
xmin = min(x(:));
ymin = min(y(:));
zmin = min(z(:));
xmax = max(x(:));
ymax = max(y(:));
zmax = max(z(:));

%Plot slice plane(s) with a 2D viewpoint
for n=1:N
    if strcmp( xyz_str,'x')
        xx = linspace(xmin,xmax,N);
        h = slice(x,y,z,v,xx(n),[],[]);
        view([1,0,0]);
        title(['x=',num2str(xx(n))])
    elseif strcmp( xyz_str,'y')
        yy = linspace(ymin,ymax,N);
        h = slice(x,y,z,v,[],yy(n),[]);
        view([0,1,0]);
        title(['y=',num2str(yy(n))])
    elseif strcmp( xyz_str,'z')
        zz = linspace(zmin,zmax,N);
        h = slice(x,y,z,v,[],[],zz(n));
        view([0,0,1]);
        title(['z=',num2str(zz(n))])
    end
    set(h,'FaceColor','interp','EdgeColor','none')
    daspect([1 1 1]);
    axis tight
    grid off;
    xlabel('x');
    ylabel('y');
    zlabel('z')
    box on
    
    %Set limits of V to correspond to colormap
    if isempty(cax)
        caxis( [vmin,vmax] );
    else
        caxis( cax );
    end
    colorbar
    
    %Save data as an indexed .png file
    saveas(gcf,[dir,'\',filename,' ',leadingzero(n,3)],'png');
    clf;
end
close(gcf);

%Montage sub-images
delete_files = 1;
montage(dir,filename,delete_files)

%%

function volume3_test

cax = [];
[x,y,z,v] = flow;
filename = 'volume3 test';
xyz_str='x';
N=12;
volume3( pwd,filename,x,y,z,v,xyz_str,N,cax )

%End of code