%plot_Hydrogen_orbital_volume
% Volume visualisation of Hydrogen atom orbitals.
%
% LAST UPDATED by Andy French March 2011.

%% This doesn't quite work - what we really want to do is visualize a surface
%% defined by a scalar field x,y,z,P, where P is the matrix of values at
%% Cartesian coordinates x,y,z

function plot_Hydrogen_orbital_volume

%Define inputs
Z = 1;
rmax = 20;
m_nuc = 1.67e-27;
n=5;
L=4;
M=-3;

%

%Construct range, azimuth and elevation matrices
num_azielev=100;
num_r = 30;
r = linspace( 0 , rmax, num_r );
azi = linspace(0,2*pi,num_azielev);
elev = linspace(-pi/2,pi/2,num_azielev);
[azi,elev] = meshgrid(azi,elev);

%Compute wavefunction, probability density function and orbital energy for
%all ranges
P=[];
x=[];
y=[];
z=[];
for k=1:num_r
    [W,PP,E] = Hwavefunc(  n, L, M, Z, m_nuc,...
        r(k)*ones(num_azielev,num_azielev), azi, elev );
    P = [P; PP];
    
    %Define x,y,z coordinate matricies
    x = [x; cos(elev).*cos(azi)];
    y = [y; cos(elev).*sin(azi)];
    z = [z; sin(elev)];
end
P( P < max(max(P))/2 ) = NaN;

%Construct and plot orbital surface
figure('color',[1 1 1],'name','Hydrogenic wave functions',...
    'units','pixels','position',[519 327 909 527]);
s=surf( x,y,z,P);
set(s,'facealpha',0.5),
title(['Hydrogenic atom probability density. Z=',num2str(Z),', m_{nuc}=',...
    num2str(m_nuc),' kg, n=',num2str(n),' L=',num2str(L),...
    ', M=',num2str(M),', E=',num2str(E),' eV' ] );
axis vis3d
axis tight
axis off
shading interp
%camlight
%lighting phong
saveas( gcf, 'hydrogen.jpg','jpg')
%close(gcf);

%End of code